pydeseq2.default_inference.DefaultInference
===========================================

.. currentmodule:: pydeseq2.default_inference

.. autoclass:: DefaultInference

   .. rubric:: Methods

   .. autosummary::

      ~DefaultInference.lin_reg_mu
      ~DefaultInference.irls
      ~DefaultInference.alpha_mle
      ~DefaultInference.wald_test
      ~DefaultInference.fit_rough_dispersions
      ~DefaultInference.fit_moments_dispersions
      ~DefaultInference.dispersion_trend_gamma_glm
      ~DefaultInference.lfc_shrink_nbinom_glm
